==> unify_api-1.1.3.tar.gz: example/lib/ui/loans.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/ui/contacts.dart';
import 'package:unify_api_example/utils/index.dart';

class LoanFolderExample extends StatelessWidget {
  final UnifyClient client;

  const LoanFolderExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Loan Folders'),
        ),
        body: LayoutBuilder(
          builder: (context, dimens) => GridView.count(
            crossAxisCount: getCrossCount(dimens),
            children: <Widget>[
              for (var folder in LoansFolder.values) ...[
                GridItem(
                  iconData: Icons.folder,
                  name: describeEnum(folder),
                  details: LoanListExample(
                    client: client,
                    loans: client.listLoans(folder: folder),
                    name: describeEnum(folder),
                  ),
                ),
              ],
            ],
          ),
        ));
  }
}

class LoanListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<Loan>> loans;
  final String name;

  const LoanListExample({
    Key key,
    @required this.client,
    @required this.loans,
    @required this.name,
  }) : super(key: key);
  @override
  _LoanListExampleState createState() => _LoanListExampleState();
}

class _LoanListExampleState extends State<LoanListExample> {
  List<Loan> _items;

  @override
  void initState() {
    widget.loans.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Loans Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.loanMilestone),
                trailing: JsonButton(json: i?.json),
                onTap: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (BuildContext context) => LoanDetailsExample(
                        loan: i.getDetails(),
                      ),
                    ),
                  );
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class LoanDetailsExample extends StatefulWidget {
  final Future<LoanDetails> loan;

  const LoanDetailsExample({Key key, @required this.loan}) : super(key: key);
  @override
  _LoanDetailsExampleState createState() => _LoanDetailsExampleState();
}

class _LoanDetailsExampleState extends State<LoanDetailsExample> {
  LoanDetails _details;

  @override
  void initState() {
    widget.loan.then((details) {
      setState(() {
        _details = details;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Loan Details"),
        actions: <Widget>[
          JsonButton(json: _details?.json),
        ],
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_details == null)
            return Center(child: CircularProgressIndicator());

          return ListView(
            children: <Widget>[
              ListTile(
                title: Text("Borrower Full Name"),
                subtitle: Text(_details.fullName),
                trailing: IconButton(
                  icon: Icon(Icons.person_outline),
                  onPressed: () async {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (BuildContext context) =>
                            ContactDetailsExample(
                                contact: _details.getBorrower()),
                      ),
                    );
                  },
                ),
              ),
              ListTile(
                title: Text("Co Borrower Full Name"),
                subtitle: Text(_details.coFullName),
              ),
              ListTile(
                title: Text("Loan Number"),
                subtitle: Text(_details?.loanNumber ?? ""),
              ),
              ListTile(
                title: Text("Loan Contacts"),
                subtitle: Text("Tap To View"),
                onTap: () async {
                  var items = await _details.listContacts();
                  List<Widget> _children = [];
                  _children = items
                      .map((i) => ListTile(
                            title: Text(i?.type ?? ""),
                            subtitle: Text(i?.name ?? ""),
                            trailing: JsonButton(json: i?.json),
                          ))
                      .toList();
                  showList(context, _children);
                },
              ),
              ListTile(
                title: Text("Loan Status"),
                subtitle: Text("Tap To View"),
                onTap: () async {
                  var i = await _details.getProgress();
                  List<Widget> _children = [];
                  _children.add(ListTile(
                    title: Text(i.name),
                    subtitle: Text(i.value.toString()),
                    trailing: JsonButton(json: i?.json),
                  ));
                  showList(context, _children);
                },
              ),
            ],
          );
        },
      ),
    );
  }
}

==> unify_api-1.2.4.tar.gz: example/lib/ui/loans.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:unify_api/unify.dart';
import 'package:unify_api_example/common/index.dart';
import 'package:unify_api_example/ui/contacts.dart';
import 'package:unify_api_example/utils/index.dart';

class LoanFolderExample extends StatelessWidget {
  final UnifyClient client;

  const LoanFolderExample({Key key, this.client}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: const Text('Loan Folders'),
        ),
        body: LayoutBuilder(
          builder: (context, dimens) => GridView.count(
            crossAxisCount: getCrossCount(dimens),
            children: <Widget>[
              for (var folder in LoansFolder.values)
                GridItem(
                  iconData: Icons.folder,
                  name: describeEnum(folder),
                  details: LoanListExample(
                    client: client,
                    loans: client.listLoans(folder: folder),
                    name: describeEnum(folder),
                  ),
                ),
              ],
          ),
        ));
  }
}

class LoanListExample extends StatefulWidget {
  final UnifyClient client;
  final Future<List<Loan>> loans;
  final String name;

  const LoanListExample({
    Key key,
    @required this.client,
    @required this.loans,
    @required this.name,
  }) : super(key: key);
  @override
  _LoanListExampleState createState() => _LoanListExampleState();
}

class _LoanListExampleState extends State<LoanListExample> {
  List<Loan> _items;

  @override
  void initState() {
    widget.loans.then((items) {
      setState(() {
        _items = items;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget?.name ?? ""),
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_items == null) return Center(child: CircularProgressIndicator());
          if (_items.isEmpty) return Center(child: Text("No Loans Found"));
          return ListView.builder(
            itemBuilder: (BuildContext context, int index) {
              final i = _items[index];
              return ListTile(
                title: Text(i.displayName),
                subtitle: Text(i.loanMilestone),
                trailing: JsonButton(json: i?.json),
                onTap: () {
                  Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (BuildContext context) => LoanDetailsExample(
                        loan: i.getDetails(),
                      ),
                    ),
                  );
                },
              );
            },
            itemCount: _items?.length ?? 0,
          );
        },
      ),
    );
  }
}

class LoanDetailsExample extends StatefulWidget {
  final Future<LoanDetails> loan;

  const LoanDetailsExample({Key key, @required this.loan}) : super(key: key);
  @override
  _LoanDetailsExampleState createState() => _LoanDetailsExampleState();
}

class _LoanDetailsExampleState extends State<LoanDetailsExample> {
  LoanDetails _details;

  @override
  void initState() {
    widget.loan.then((details) {
      setState(() {
        _details = details;
      });
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Loan Details"),
        actions: <Widget>[
          JsonButton(json: _details?.json),
        ],
      ),
      body: Builder(
        builder: (BuildContext context) {
          if (_details == null)
            return Center(child: CircularProgressIndicator());

          return ListView(
            children: <Widget>[
              ListTile(
                title: Text("Borrower Full Name"),
                subtitle: Text(_details.fullName),
                trailing: IconButton(
                  icon: Icon(Icons.person_outline),
                  onPressed: () async {
                    Navigator.push(
                      context,
                      MaterialPageRoute(
                        builder: (BuildContext context) =>
                            ContactDetailsExample(
                                contact: _details.getBorrower()),
                      ),
                    );
                  },
                ),
              ),
              ListTile(
                title: Text("Co Borrower Full Name"),
                subtitle: Text(_details.coFullName),
              ),
              ListTile(
                title: Text("Loan Number"),
                subtitle: Text(_details?.loanNumber ?? ""),
              ),
              ListTile(
                title: Text("Loan Contacts"),
                subtitle: Text("Tap To View"),
                onTap: () async {
                  var items = await _details.listContacts();
                  List<Widget> _children = [];
                  _children = items
                      .map((i) => ListTile(
                            title: Text(i?.type ?? ""),
                            subtitle: Text(i?.name ?? ""),
                            trailing: JsonButton(json: i?.json),
                          ))
                      .toList();
                  showList(context, _children);
                },
              ),
              ListTile(
                title: Text("Loan Status"),
                subtitle: Text("Tap To View"),
                onTap: () async {
                  var i = await _details.getProgress();
                  List<Widget> _children = [];
                  _children.add(ListTile(
                    title: Text(i.name),
                    subtitle: Text(i.value.toString()),
                    trailing: JsonButton(json: i?.json),
                  ));
                  showList(context, _children);
                },
              ),
            ],
          );
        },
      ),
    );
  }
}
